@@ -1,7 +1,8 @@
 from django import template
 # from django.templatetags.static import static
 # see stackoverflow :http://stackoverflow.com/questions/11721818
-from django.contrib.staticfiles.templatetags.staticfiles import static 
+from django.templatetags.static import static 
+from django.utils.safestring import mark_safe
 
 register = template.Library()
 
@@ -24,8 +25,8 @@ def selectize_tags_media(media_type='css',name=''):
 		html=str_script.format(url=static('selectize/selectize.min.js'))
 		if name=='jquery':
 			html=str_script.format(url=static('selectize/jquery.min.js'))+html
-		return html
+		return mark_safe(html)
 
 	if name:name+='.'
 	fpath='selectize/css/selectize.{name}css'.format(name=name)
-	return '<link rel="stylesheet" href="{url}">'.format(url=static(fpath))
\ No newline at end of file
+	return mark_safe('<link rel="stylesheet" href="{url}">'.format(url=static(fpath)))
\ No newline at end of file
